;; Generated package description from drepl.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "drepl" "0.4.0.20251012.81518" "REPL protocol for the dumb terminal" '((emacs "29.1") (comint-mime "0.7")) :commit "f37cac8ebefdb0f517cbb344fe62c1e5287b2255" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("languages" "processes") :url "https://github.com/astoff/drepl")
